class UnknownAccountError(Exception):
    pass


class TransactionRevertError(Exception):
    pass


class NetworkError(Exception):
    pass


class SignerError(Exception):

    def __init__(self, s):
        super(SignerError, self).__init__(s)
        self.jsonrpc_error = s


    def to_jsonrpc(self):
        return self.jsonrpc_error


class DecryptError(Exception):
    pass


class KeyfileError(Exception):
    pass



from setuptools import setup

f = open('README.md', 'r')
long_description = f.read()
f.close()

requirements = []
f = open('requirements.txt', 'r')
while True:
    l = f.readline()
    if l == '':
        break
    requirements.append(l.rstrip())
f.close()

test_requirements = []
f = open('test_requirements.txt', 'r')
while True:
    l = f.readline()
    if l == '':
        break
    test_requirements.append(l.rstrip())
f.close()

setup(
        name="funga",
        version="0.5.2",
        description="A signer and keystore daemon and library for cryptocurrency software development",
        author="Louis Holbrook",
        author_email="dev@holbrook.no",
        packages=[
            'funga',
            ],
        install_requires=requirements,
        tests_require=test_requirements,
        long_description=long_description,
        long_description_content_type='text/markdown',
       url='https://git.grassecon.net/chaintool/funga',
        )



# standard imports
import os
import json
import logging

logg = logging.getLogger(__name__)


class Keystore:


    def __init__(self, private_key_generator, private_key_parser, keystore_parser):
        self.private_key_generator = private_key_generator
        self.private_key_parser = private_key_parser
        self.keystore_parser = keystore_parser


    def get(self, address, password=None):
        raise NotImplementedError


    def list(self):
        raise NotImplementedError


    def lock(self, address=None):
        raise NotImplementedError
       

    def unlock(self, address=None):
        raise NotImplementedError


    def new(self, password=None):
        self.private_key_generator(password=password)
       

    def import_raw_key(self, b, password=None):
        pk = self.private_key_parser(b)
        return self.import_key(pk, password)


    def import_key(self, pk, password=None):
        raise NotImplementedError


    def import_keystore_data(self, keystore_content, password=''):
        private_key = self.keystore_parser(keystore_content, password.encode('utf-8'))
        return self.import_raw_key(private_key, password=password)


    def import_keystore_file(self, keystore_file, password=''):
        private_key = self.keystore_parser(keystore_file, password)
        return self.import_raw_key(private_key, password=password)
